@@ -24,7 +24,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.7.7';
+our $VERSION = '3.7.8';
 
 =head1 SYNOPSIS
 
@@ -183,9 +183,9 @@ sub new {
 }
 
 sub page_token {
-    my ($self) = @_;
+    my ($self, $number) = @_;
 
-    my $page = $self->get_page;
+    my $page = $number // $self->get_page;
 
     # Don't generate the token for the first page
     return undef if $page == 1;
@@ -493,9 +493,9 @@ sub _extract_from_invidious {
     my ($self, $videoID) = @_;
 
     my @instances = qw(
-      invidio.us
       invidious.snopyta.org
       invidious.13ad.de
+      invidious.tube
       );
 
     my $tries      = 2 * scalar(@instances);
@@ -830,8 +830,7 @@ sub get_streaming_urls {
     my @caption_urls;
     if (exists $info{player_response}) {
 
-        require URI::Escape;
-        my $captions_json = URI::Escape::uri_unescape($info{player_response});
+        my $captions_json = $info{player_response};                     # don't run uri_unescape() on this
         my $caption_data  = $self->parse_json_string($captions_json);
 
         if (eval { ref($caption_data->{captions}{playerCaptionsTracklistRenderer}{captionTracks}) eq 'ARRAY' }) {
@@ -863,10 +862,12 @@ sub get_streaming_urls {
             }
 
             if ($url->{type} =~ /\bvideo\b/i) {
-                if ($self->get_prefer_mp4 and $url->{type} =~ /\bmp4\b/i) {
-                    push @video_urls, $url;
+                if ($url->{type} =~ /\bav[0-9]+\b/i) {    # AV1
+                    if ($self->get_prefer_av1) {
+                        push @video_urls, $url;
+                    }
                 }
-                elsif ($self->get_prefer_av1 and $url->{type} =~ /\bav[0-9]+\b/i) {
+                elsif ($self->get_prefer_mp4 and $url->{type} =~ /\bmp4\b/i) {
                     push @video_urls, $url;
                 }
             }
@@ -950,27 +951,28 @@ sub post_as_json {
     $self->_save('POST', $url, $json_str);
 }
 
+sub from_page_token {
+    my ($self, $url, $token) = @_;
+
+    my $pt_url = (
+                  defined($token)
+                  ? (
+                     ($url =~ s/[?&]pageToken=\K[^&]+/$token/)
+                     ? $url
+                     : $self->_append_url_args($url, pageToken => $token)
+                    )
+                  : ($url =~ s/[?&]pageToken=[^&]+//r)
+                 );
+
+    my $res = $self->_get_results($pt_url);
+    $res->{url} = $pt_url;
+    return $res;
+}
+
 # SUBROUTINE FACTORY
 {
     no strict 'refs';
 
-    # Create {next,previous}_page subroutines
-    foreach my $name ('next_page', 'previous_page') {
-        *{__PACKAGE__ . '::' . $name} = sub {
-            my ($self, $url, $token) = @_;
-
-            my $pt_url = (
-                            $url =~ s/[?&]pageToken=\K[^&]+/$token/
-                          ? $url
-                          : $self->_append_url_args($url, pageToken => $token)
-                         );
-
-            my $res = $self->_get_results($pt_url);
-            $res->{url} = $pt_url;
-            return $res;
-        };
-    }
-
     # Create proxy_{exec,system} subroutines
     foreach my $name ('exec', 'system', 'stdout') {
         *{__PACKAGE__ . '::proxy_' . $name} = sub {
